This function creates a payoffs layer that can be added to a twig object. The payoffs layer defines the payoffs and their associated discount rates.
Usage
payoffs(names, discount_rates = NULL)
Value
A list representing the payoffs layer.
Arguments
names
A character vector of payoff function names. They don't need to be included in quotes.
discount_rates
A numeric vector of discount rates for each payoff. If NULL, a discount rate of 0 is assumed for each payoff.
discount_rates must have the same length as payoff names.